summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendardelete.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konsolekalendar/konsolekalendardelete.cpp')
-rw-r--r--konsolekalendar/konsolekalendardelete.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/konsolekalendar/konsolekalendardelete.cpp b/konsolekalendar/konsolekalendardelete.cpp
index 02d67627..b3f27650 100644
--- a/konsolekalendar/konsolekalendardelete.cpp
+++ b/konsolekalendar/konsolekalendardelete.cpp
@@ -20,8 +20,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
* *
* As a special exception, permission is given to link this program *
* with any edition of Qt, and distribute the resulting executable, *
* without including the source code for Qt in the source distribution. *
* *
******************************************************************************/
/**
@@ -101,11 +101,11 @@ void KonsoleKalendarDelete::printSpecs( Event *event )
<< endl;
cout << i18n( " Begin: %1" ).
- arg( event->dtStart().toString( Qt::TextDate ) ).local8Bit()
+ arg( event->dtStart().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " End: %1" ).
- arg( event->dtEnd().toString( Qt::TextDate ) ).local8Bit()
+ arg( event->dtEnd().toString( TQt::TextDate ) ).local8Bit()
<< endl;
cout << i18n( " Desc: %1" ).
@@ -20,8 +20,8 @@
* *
* As a special exception, permission is given to link this program *
- * with any edition of Qt, and distribute the resulting executable, *
- * without including the source code for Qt in the source distribution. *
+ * with any edition of TQt, and distribute the resulting executable, *
+ * without including the source code for TQt in the source distribution. *
* *
******************************************************************************/